FL.objects.TTInfo.TTInfo
========================

.. currentmodule:: FL.objects.TTInfo

.. autoclass:: TTInfo
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TTInfo.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TTInfo.cvt
      ~TTInfo.fpgm
      ~TTInfo.gasp
      ~TTInfo.hdmx
      ~TTInfo.head_creation
      ~TTInfo.head_flags
      ~TTInfo.head_font_direction_hint
      ~TTInfo.head_lowest_rec_ppem
      ~TTInfo.head_mac_style
      ~TTInfo.head_units_per_em
      ~TTInfo.hhea_ascender
      ~TTInfo.hhea_descender
      ~TTInfo.hhea_line_gap
      ~TTInfo.hstem_data
      ~TTInfo.max_function_defs
      ~TTInfo.max_instruction_defs
      ~TTInfo.max_stack_elements
      ~TTInfo.max_storage
      ~TTInfo.max_twilight_points
      ~TTInfo.max_zones
      ~TTInfo.os2_fs_selection
      ~TTInfo.os2_fs_type
      ~TTInfo.os2_s_family_class
      ~TTInfo.os2_s_typo_ascender
      ~TTInfo.os2_s_typo_descender
      ~TTInfo.os2_s_typo_line_gap
      ~TTInfo.os2_ul_code_page_range1
      ~TTInfo.os2_ul_code_page_range2
      ~TTInfo.os2_us_weight_class
      ~TTInfo.os2_us_width_class
      ~TTInfo.os2_us_win_ascent
      ~TTInfo.os2_us_win_descent
      ~TTInfo.os2_y_strikeout_position
      ~TTInfo.os2_y_strikeout_size
      ~TTInfo.os2_y_subscript_x_offset
      ~TTInfo.os2_y_subscript_x_size
      ~TTInfo.os2_y_subscript_y_offset
      ~TTInfo.os2_y_subscript_y_size
      ~TTInfo.os2_y_superscript_x_offset
      ~TTInfo.os2_y_superscript_x_size
      ~TTInfo.os2_y_superscript_y_offset
      ~TTInfo.os2_y_superscript_y_size
      ~TTInfo.prep
      ~TTInfo.vdmx
      ~TTInfo.vstem_data
   
   